"""
********************************************************************************
compas.interop
********************************************************************************

.. currentmodule:: compas.interop

.. warning::

    The functionality of this package is experimental and subject to frequent change.
    For now, don't use it for anything important :)


C++
===

.. autosummary::
    :toctree: generated/
    :nosignatures:

    cpp.xdarray.Array1D
    cpp.xdarray.Array2D
    cpp.xdarray.Array3D
    cpp.xdarray.shape
    cpp.xdarray.zeros
    cpp.xdarray.ones
    cpp.xdarray.eye


CSharp
======

.. autosummary::
    :toctree: generated/
    :nosignatures:


Fortran
=======

.. autosummary::
    :toctree: generated/
    :nosignatures:

"""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

__all__ = []
